@@ -2,5 +2,5 @@ from ..node import Node
 
 
 class Session(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
