@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 
 class BlocksActionBuilder(object):
@@ -69,7 +69,11 @@ class BlocksActionBuilder(object):
         )
 
     def add_text_field(
-        self, title: str, required: bool = False, id: str = None, suggestions: List[str] = None
+        self,
+        title: str,
+        required: bool = False,
+        id: str = None,
+        suggestions: Optional[List[str]] = [],
     ):
         return self.add_block(
             {
