@@ -1,4 +1,4 @@
-from typing import Any, List
+from typing import Any, List, Optional
 
 
 class StepBuilder(object):
@@ -75,7 +75,11 @@ class StepBuilder(object):
         )
 
     def add_text_field(
-        self, title: str, required: bool = False, id: str = None, suggestions: List[str] = None
+        self,
+        title: str,
+        required: bool = False,
+        id: str = None,
+        suggestions: Optional[List[str]] = [],
     ):
         return self.add_block(
             {
